==> radare2_2.3.0+dfsg.orig.tar.xz: radare2-2.3.0/AUTHORS.md <==
Authors
=======

Main developer (author and maintainer)
--------------------------------------

The author of radare and radare2, is the main contributor and designer of the tool, apis, bindings, etc

 - pancake <pancake@nopcode.org>


Mentors and co-maintainers
--------------------------

Most active in community, setting up CI servers, regression tests, esil, coverity, blog, release notes, ..

 - xvilka
 - condret
 - crowell
 - jvoisin
 - maijin

Honoric Contributors
--------------------

Special mention for showing great interest and helping the project in fuzzing, bug fixing, the new web ui, r2pipe, PDB, windows support (console, debugger, windbg), ..

 - Alvaro Felipe
 - NighterMan
 - Reverse Skills
 - Skuater
 - inisider
 - pwntester
 - ret2libc
 - zlul

GSoC/RSOC
---------

Participants from the previous Summer Of Code competition which keep contributing to the project with better `pf`, console highlights, flirt signatures, yara, decompiler,. .

 - Jody Frankowski
 - Skia
 - Sushant
 - dkreuter

Contributors
------------

This release comes with contributions from the following people:

 - Aaron Puchert
 - Anton Devil
 - Asger Hautop Drewsen
 - Clement Vuchener
 - David Weinstein
 - Elias Boutaleb
 - Gabriel Corona
 - James Sullivan1
 - Jasper St.Pierre
 - Jeff Muizelaar
 - Jonathan Neuschafer
 - Judge Dredd (jjdredd, Rahim Usubov)
 - Julien Nabet
 - Kai Renken
 - Kamil Rytarowski
 - Monokles
 - Nick Stephens
 - Pavel Odvoby
 - Quentin Santos
 - Ravi Bhoot
 - Ryan Hileman
 - TheLemonMan
 - ampotos
 - capi_x
 - cosarara
 - damo22
 - dso (Adam Pridgen)
 - dunhame
 - dx
 - fenugrec
 - jackflash
 - kroemeke
 - mauromateo
 - mortenoir
 - nibble
 - ninjahacker
 - r0nk
 - s4lv0
 - sirmy
 - trndr
 - zlowram

Previous contributors
---------------------

Some people didn't contributed to the last release, but they did it for the past ones. Kudos for them too!

 - 0xroot
 - Alexander
 - Anton Bolotinksy
 - Eduardo Arada
 - elektranox
 - Eloi Sanfelix
 - Esteve Espunya
 - Javier Segura (graz)
 - Glyn Kennington
 - l0gic
 - milabs
 - montekki
 - neuroflip
 - nion
 - oxff
 - Pau Oliva Fora (pof)
 - Roc Vallès (rvalles)
 - rudi_s
 - schrotthaufen
 - timstrazz
 - vext01

==> radare2_3.2.1+dfsg.orig.tar.xz: radare2-3.2.1/AUTHORS.md <==
Authors
=======

Main developer (author and maintainer)
--------------------------------------

The author of radare and radare2 is the main contributor and designer of the tool, apis, bindings, etc.

 - pancake <pancake@nopcode.org>


Mentors and co-maintainers
--------------------------

Most active in community, setting up CI servers, regression tests, esil, coverity, blog, release notes, ..

 - xvilka
 - condret
 - crowell
 - jvoisin
 - maijin

Honoric Contributors
--------------------

Special mention for showing great interest and helping the project in fuzzing, bug fixing, the new web ui, r2pipe, PDB, windows support (console, debugger, windbg), ..

 - Alvaro Felipe
 - NighterMan
 - Reverse Skills
 - Skuater
 - inisider
 - pwntester
 - ret2libc
 - zlul

GSoC/RSOC
---------

Participants from the previous Summer Of Code competition which keep contributing to the project with better `pf`, console highlights, flirt signatures, yara, decompiler,. .

 - Jody Frankowski
 - Skia
 - Sushant
 - dkreuter

Contributors
------------

This release comes with contributions from the following people:

 - Aaron Puchert
 - Anton Devil
 - Asger Hautop Drewsen
 - Clement Vuchener
 - David Weinstein
 - Elias Boutaleb
 - Gabriel Corona
 - James Sullivan1
 - Jasper St.Pierre
 - Jeff Muizelaar
 - Jonathan Neuschafer
 - Judge Dredd (jjdredd, Rahim Usubov)
 - Julien Nabet
 - Kai Renken
 - Kamil Rytarowski
 - Monokles
 - Nick Stephens
 - Pavel Odvoby
 - Quentin Santos
 - Ravi Bhoot
 - Ryan Hileman
 - TheLemonMan
 - ampotos
 - capi_x
 - cosarara
 - damo22
 - dso (Adam Pridgen)
 - dunhame
 - dx
 - fenugrec
 - jackflash
 - kroemeke
 - mauromateo
 - mortenoir
 - nibble
 - ninjahacker
 - r0nk
 - s4lv0
 - sirmy
 - trndr
 - zlowram

Previous contributors
---------------------

Some people didn't contribute to the lastest release, but they did it for the past ones. Kudos for them too!

 - 0xroot
 - Alexander
 - Anton Bolotinksy
 - Eduardo Arada
 - elektranox
 - Eloi Sanfelix
 - Esteve Espunya
 - Javier Segura (graz)
 - Glyn Kennington
 - l0gic
 - milabs
 - montekki
 - neuroflip
 - nion
 - oxff
 - Pau Oliva Fora (pof)
 - Roc Vallès (rvalles)
 - rudi_s
 - schrotthaufen
 - timstrazz
 - vext01
